@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.29 2003/10/02 19:16:16 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.31 2003/12/03 22:20:03 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -407,6 +407,12 @@ do_delete()     /* Remove the last numeric character typed. */
 
     set_display(v->display);
     MPstr_to_num(v->display, v->base, v->MPdisp_val);
+
+    if (v->dtype == FIX) {
+        STRCPY(v->fnum, v->display);
+        add_tsep();
+        set_display(v->fnum);
+    }
 }
 
 
@@ -691,7 +697,7 @@ do_paren()
         }
         v->noparens--;
         if (!v->noparens) {
-            paren_disp(v->current->value[0]);
+            paren_disp(v->current->func_char);
             ptr = v->display;
             while (*ptr != '(') {
                 ptr++;
@@ -702,7 +708,7 @@ do_paren()
             return;
         }
     }
-    paren_disp(v->current->value[0]);
+    paren_disp(v->current->func_char);
 }
 
 
